from packgram.project import ProjectModule


class ProjectModule(ProjectModule):

    # Attributes

    author = 'roll'
    author_email = 'roll@respect31.com'
    copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
    description = 'Clyde is a command line interface designer.'
    development_requires = ['packgram>=0.25']
    github_user = 'clyde-hub'
    install_requires = ['sugarbowl', 'jinja2']
    interpreters = ['3.3', '3.4']
    license = 'MIT License'
    name = 'clyde'
    platforms = ['Unix']
    pypi_password_secure = 'bjVGVG2Gkj9vm65t0BwVqGRTqi6o2qqOFVCo6X7KCfZdrBdL2u7EaNpDqhj8//ITpn5bZsnPWmLXuZEhhStc/kbJpMOgfciIuSZW6IChTiFnUgwK/F/yndhD7G0D6n6hbQ/mCT7KPaH3omZWspjcNdhyhn/NaWD9mZbhrcmPLN8='
    tests_require = ['nose', 'coverage']
    test_suite = 'nose.collector'
    version = '0.7.0'
